@@ -180,11 +180,11 @@ class ElementWrapper(object):
 
 
     @when("a[@href]")
-    def click(self, follow=True):
+    def click(self, follow=True, check_status=True):
         """
         Follow a link and return a new instance of ``TestAgent``
         """
-        return self.agent._click(self, follow=follow)
+        return self.agent._click(self, follow=follow, check_status=check_status)
 
     @when("input[@type='checkbox']")
     def _get_value(self):
@@ -429,20 +429,20 @@ class ElementWrapper(object):
         return self.__class__(self.agent, self.element.xpath("./ancestor-or-self::form[1]")[0])
 
     @when("input[@type='submit' or @type='image']|button[@type='submit' or not(@type)]")
-    def submit(self, follow=True):
+    def submit(self, follow=True, check_status=True):
         """
         Submit the form, returning a new ``TestAgent`` object, by clicking on
         the selected submit element (input of
         type submit or image, or button with type submit)
         """
-        return self.form.submit(self, follow)
+        return self.form.submit(self, follow, check_status=check_status)
 
     @when("input[@type='submit' or @type='image']|button[@type='submit' or not(@type)]")
-    def click(self, follow=True):
+    def click(self, follow=True, check_status=True):
         """
         Alias for submit
         """
-        return self.submit(follow)
+        return self.submit(follow, check_status=check_status)
 
     @when("input[@type='submit' or @type='image']|button[@type='submit' or not(@type)]")
     def submit_data(self):
@@ -454,7 +454,7 @@ class ElementWrapper(object):
         return self.form.submit_data(self)
 
     @when("form")
-    def submit(self, button=None, follow=True):
+    def submit(self, button=None, follow=True, check_status=True):
         """
         Submit the form, returning a new ``TestAgent`` object
         """
@@ -469,7 +469,7 @@ class ElementWrapper(object):
             ('POST', None): self.agent.post,
             ('POST', 'application/x-www-form-urlencoded'): self.agent.post,
             ('POST', 'multipart/form-data'): self.agent.post_multipart,
-        }[(method, self.element.attrib.get('enctype'))](path, data, follow=follow)
+        }[(method, self.element.attrib.get('enctype'))](path, data, follow=follow, check_status=check_status)
 
     @when("form")
     def submit_data(self, button=None):
@@ -759,6 +759,23 @@ class TestAgent(object):
     def _request(self, environ, follow=True, history=False, check_status=True):
         """
         Low level entry point for making requests to the WSGI application.
+
+        Return a TestAgent object representing the new state resulting from the
+        request.
+
+        environ
+            WSGI environ to be used for the request
+
+        follow
+            If false, redirect responses will not be followed
+
+        history
+            If true, a new entry will be added to the history attribute for the
+            resulting TestAgent object
+
+        check_status
+            If true, any non success HTTP status code will result in an
+            AssertionError being raised
         """
         path = environ['SCRIPT_NAME'] + environ['PATH_INFO']
         environ['HTTP_COOKIE'] = '; '.join(
@@ -794,7 +811,7 @@ class TestAgent(object):
             return agent.follow_all()
         return agent
 
-    def get(self, PATH_INFO='/', data=None, charset='UTF-8', follow=True, history=True, **kwargs):
+    def get(self, PATH_INFO='/', data=None, charset='UTF-8', follow=True, history=True, check_status=True, **kwargs):
         """
         Make a GET request to the application and return the response.
 
@@ -812,6 +829,15 @@ class TestAgent(object):
 
         follow
             If false, redirect responses will not be followed
+
+        history
+            If true, a new entry will be added to the history attribute for the
+            resulting TestAgent object
+
+        check_status
+            If true, any non success HTTP status code will result in an
+            AssertionError being raised
+
         """
         if data is not None:
             kwargs.setdefault('QUERY_STRING', make_query(data, charset=charset))
@@ -827,9 +853,10 @@ class TestAgent(object):
             ),
             follow,
             history,
+            check_status,
         )
 
-    def post(self, PATH_INFO='/', data=None, charset='UTF-8', follow=True, history=True, **kwargs):
+    def post(self, PATH_INFO='/', data=None, charset='UTF-8', follow=True, history=True, check_status=True, **kwargs):
         """
         Make a POST request to the application and return the response.
 
@@ -846,6 +873,15 @@ class TestAgent(object):
         follow
             If false, redirect responses will not be followed
 
+        history
+            If true, a new entry will be added to the history attribute for the
+            resulting TestAgent object
+
+        check_status
+            If true, any non success HTTP status code will result in an
+            AssertionError being raised
+
+
         """
         if data is None:
             data = []
@@ -868,9 +904,10 @@ class TestAgent(object):
             ),
             follow,
             history,
+            check_status,
         )
 
-    def post_multipart(self, PATH_INFO='/', data=None, files=None, charset='UTF-8', follow=True, **kwargs):
+    def post_multipart(self, PATH_INFO='/', data=None, files=None, charset='UTF-8', follow=True, history=True, check_status=True, **kwargs):
         """
         POST a request to the given URI using multipart/form-data encoding.
 
@@ -884,6 +921,15 @@ class TestAgent(object):
         files
             list of ``(name, filename, content_type, data)`` tuples. ``data``
             may be either a byte string, iterator or file-like object.
+
+        history
+            If true, a new entry will be added to the history attribute for the
+            resulting TestAgent object
+
+        check_status
+            If true, any non success HTTP status code will result in an
+            AssertionError being raised
+
         """
 
         if data is None:
@@ -954,6 +1000,8 @@ class TestAgent(object):
                 **kwargs
             ),
             follow=follow,
+            history=history,
+            check_status=check_status,
         )
 
     def start_response(self, status, headers, exc_info=None):
@@ -1014,13 +1062,14 @@ class TestAgent(object):
         """
         return self.root_element.findcss(selector)
 
-    def click(self, path, follow=True, **kwargs):
-        return self.find(path, **kwargs).click(follow=follow)
+    def click(self, path, follow=True, check_status=True, **kwargs):
+        return self.find(path, **kwargs).click(follow=follow, check_status=check_status)
 
-    def _click(self, element, follow=True):
+    def _click(self, element, follow=True, check_status=True):
         return self.get(
             element.attrib['href'],
-            follow=follow
+            follow=follow,
+            check_status=check_status,
         )
 
     def follow(self):
@@ -1155,7 +1204,7 @@ def uri_join_same_server(baseuri, uri):
         >>> uri_join_same_server('http://localhost/foo', 'http://localhost/bar')
         '/bar'
         >>> uri_join_same_server('http://localhost/rhubarb/custard/', '../')
-        '/rhubarb'
+        '/rhubarb/'
         >>> uri_join_same_server('http://localhost/foo', 'http://example.org/bar')
         Traceback (most recent call last):
           ...
